<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>@default</name>
    <message>
        <source>Notifications</source>
        <translation>Powiadomienia</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation>
            <numerusform>%n sekunda</numerusform>
            <numerusform>%n sekundy</numerusform>
            <numerusform>%n sekund</numerusform>
        </translation>
    </message>
    <message>
        <source>Show message content</source>
        <translation>Pokaż treść wiadomości</translation>
    </message>
    <message>
        <source>Number of quoted characters</source>
        <translation>Liczba cytowanych znaków</translation>
    </message>
    <message>
        <source>System notifications</source>
        <translation>Powiadomienia systemowe</translation>
    </message>
    <message>
        <source>Use custom expiration timeout</source>
        <translation>Użyj własnego czasu zanikania</translation>
    </message>
    <message>
        <source>Expiration timeout</source>
        <translation>Czas zanikania</translation>
    </message>
</context>
</TS>
